@@ -237,7 +237,7 @@ def extract_by_var(vars, state_codes,
             if not os.path.exists(export_tmp_fp):
                 result_df.to_parquet(export_tmp_fp, compression='gzip')
             else:
-                cols_to_use = tmp_df.columns.difference(result_df.columns)
+                cols_to_use = result_df.columns.difference(tmp_df.columns)
                 print(cols_to_use)
                 tmp_df = pd.merge(tmp_df, results_df[cols_to_use], left_index=True, right_index=True, how='left')
                 # tmp_df = result_df.join(tmp_df, how='left')
